Learn R Programming

mmapcharr (version 0.3.0)

mmapchar-methods: Methods for the mmapchar class

Description

Methods for the mmapchar class

Accessor methods for class mmapchar. You can use positive and negative indices, logical indices (that are recycled) and also a matrix of indices (but only positive ones).

Dimension and type methods for class mmapchar.

Usage

# S4 method for mmapchar
[(x, i, j, ..., drop = TRUE)

# S4 method for mmapchar dim(x)

# S4 method for mmapchar length(x)

Arguments

x

A mmapchar object.

i

A vector of indices (or nothing). You can use positive and negative indices, logical indices (that are recycled) and also a matrix of indices (but only positive ones).

j

A vector of indices (or nothing). You can use positive and negative indices, logical indices (that are recycled).

...

Not used. Just to make nargs works.

drop

Whether to delete the dimensions of a matrix which have one dimension equals to 1.