Learn R Programming

mmapcharr (version 0.3.0)

nelem: Size of line

Description

Number of elements of each line of a file.

Usage

nelem(file)

Value

The number of elements of each line of a file.

Arguments

file

Path to file.

Examples

Run this code
tmpfile <- tempfile()
write(1:10, tmpfile, ncolumns = 2)
nline(tmpfile)

Run the code above in your browser using DataLab