Methods for the mmapchar class
Accessor methods for class mmapchar. You can use positive and negative indices,
logical indices (that are recycled) and also a matrix of indices (but only
positive ones).
Dimension and type methods for class mmapchar.
# S4 method for mmapchar
[(x, i, j, ..., drop = TRUE)# S4 method for mmapchar
dim(x)
# S4 method for mmapchar
length(x)
A mmapchar object.
A vector of indices (or nothing). You can use positive and negative indices, logical indices (that are recycled) and also a matrix of indices (but only positive ones).
A vector of indices (or nothing). You can use positive and negative indices, logical indices (that are recycled).
Not used. Just to make nargs works.
Whether to delete the dimensions of a matrix which have one dimension equals to 1.