powered by
Number of elements of each line of a file.
nelem(file)
The number of elements of each line of a file.
Path to file.
tmpfile <- tempfile() write(1:10, tmpfile, ncolumns = 2) nline(tmpfile)
Run the code above in your browser using DataLab